@@ -1,6 +1,6 @@
 from sklearn.mixture import GaussianMixture
-from SpatialCluster.methods.functions import get_areas
-
+from SpatialCluster.utils.get_areas import get_areas
+from SpatialCluster.utils.data_format import data_format, position_data_format
 
 """
 ----------------
@@ -18,6 +18,8 @@ areas_to_points:    (dict) Dictionary with the cluster id as keys and a list of
 """
 
 def GMM_Clustering(features_X, features_position, n_components = 2, tol=1e-3, reg_covar=1e-6):
+    features_X = data_format(features_X)
+    features_position = position_data_format(features_position)
     points = list(zip(features_position.lon, features_position.lat))
     gmm = GaussianMixture(n_components=n_components, tol=tol, reg_covar=reg_covar).fit(features_X)
     clusters = gmm.predict(features_X)
